:mod:`cybox.objects.archive_file_object` module
===============================================

.. automodule:: cybox.objects.archive_file_object
    :members:
    :undoc-members:
    :show-inheritance:
